@@ -131,7 +131,6 @@ list__process_line (char     *line,
 		
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	} else if (arj_comm->line_no == 2) { /* Read file size and date. */
 		FileData  *fdata;
@@ -141,9 +140,10 @@ list__process_line (char     *line,
 
 		/* read file info. */
 		
-		fields = split_line (line, 7);
+		fields = split_line (line, 10);
 		fdata->size = g_ascii_strtoull (fields[2], NULL, 10);
 		fdata->modified = mktime_from_string (fields[5], fields[6]); 
+		fdata->encrypted = (g_ascii_strcasecmp (fields[9], "11") == 0);
 		g_strfreev (fields);
 		
 		if (*fdata->name == 0)
@@ -158,7 +158,8 @@ list__process_line (char     *line,
 
 
 static void
-fr_command_arj_list (FRCommand *comm)
+fr_command_arj_list (FRCommand  *comm,
+		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      list__process_line,
@@ -281,7 +282,8 @@ fr_command_arj_extract (FRCommand  *comm,
 		char *swtch = g_strconcat ("-g/", password, NULL);
 		fr_process_add_arg (comm->process, swtch);
 		g_free (swtch);
-	}
+	} else
+ 		fr_process_add_arg (comm->process, "-g/");
 
 	fr_process_add_arg (comm->process, "-i");
 	fr_process_add_arg (comm->process, "-y");
@@ -319,7 +321,12 @@ static void
 fr_command_arj_handle_error (FRCommand   *comm, 
 			     FRProcError *error)
 {
-	/* FIXME */
+	if (error->type == FR_PROC_ERROR_GENERIC) {
+ 		if (error->status <= 1)
+ 			error->type = FR_PROC_ERROR_NONE;
+		else if (error->status == 3) 
+ 			error->type = FR_PROC_ERROR_ASK_PASSWORD;
+ 	}
 }
 
 
