@@ -134,7 +134,6 @@ process_line (char     *line,
 		
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	} else {
 		FileData *fdata;
@@ -181,14 +180,14 @@ add_password_arg (FRCommand	*comm,
 		
 		g_free (e_password);
 		g_free (arg);
-	} else if (disable_query) {
+	} else if (disable_query) 
 		fr_process_add_arg (comm->process, "-p-");
-	}
 }
 
 
 static void
-fr_command_rar_list (FRCommand *comm)
+fr_command_rar_list (FRCommand  *comm,
+		     const char *password)
 {
 	FR_COMMAND_RAR (comm)->list_started = FALSE;
 
@@ -203,9 +202,7 @@ fr_command_rar_list (FRCommand *comm)
 	fr_process_add_arg (comm->process, "v");
 	fr_process_add_arg (comm->process, "-c-");
 
-	/* Fixme: listing rar archives fails when headers and data
-	          are encrypted (-hp option) without a password. */
-	add_password_arg (comm, NULL, TRUE);
+	add_password_arg (comm, password, TRUE);
 	
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--"); 
@@ -364,9 +361,13 @@ static void
 fr_command_rar_handle_error (FRCommand   *comm, 
 			     FRProcError *error)
 {
-	if ((error->type == FR_PROC_ERROR_GENERIC) 
-	    && (error->status <= 1))
-		error->type = FR_PROC_ERROR_NONE;
+	if (error->type == FR_PROC_ERROR_GENERIC) {
+		if (error->status <= 1)
+			error->type = FR_PROC_ERROR_NONE;
+		else if (error->status == 3)
+			error->type = FR_PROC_ERROR_ASK_PASSWORD;
+	} else if (error->type == FR_PROC_ERROR_EXITED_ABNORMALLY)
+		error->type = FR_PROC_ERROR_ASK_PASSWORD;
 }
 
 
