@@ -190,7 +190,7 @@ unescape_str (const char  *str)
 char*
 shell_escape (const char *filename)
 {
-	return escape_str (filename, "$\'`\"\\!?* ()[]&|:;");
+	return escape_str (filename, "$\'`\"\\!?* ()[]&|:;<>");
 }
 
 
